@@ -253,20 +253,20 @@ def test_artifact_registry_client_client_options(
     # unsupported value.
     with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS_ENDPOINT": "Unsupported"}):
         with pytest.raises(MutualTLSChannelError):
-            client = client_class()
+            client = client_class(transport=transport_name)
 
     # Check the case GOOGLE_API_USE_CLIENT_CERTIFICATE has unsupported value.
     with mock.patch.dict(
         os.environ, {"GOOGLE_API_USE_CLIENT_CERTIFICATE": "Unsupported"}
     ):
         with pytest.raises(ValueError):
-            client = client_class()
+            client = client_class(transport=transport_name)
 
     # Check the case quota_project_id is provided
     options = client_options.ClientOptions(quota_project_id="octopus")
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(transport=transport_name, client_options=options)
+        client = client_class(client_options=options, transport=transport_name)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file=None,
@@ -335,7 +335,7 @@ def test_artifact_registry_client_mtls_env_auto(
         )
         with mock.patch.object(transport_class, "__init__") as patched:
             patched.return_value = None
-            client = client_class(transport=transport_name, client_options=options)
+            client = client_class(client_options=options, transport=transport_name)
 
             if use_client_cert_env == "false":
                 expected_client_cert_source = None
@@ -430,7 +430,7 @@ def test_artifact_registry_client_client_options_scopes(
     options = client_options.ClientOptions(scopes=["1", "2"],)
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(transport=transport_name, client_options=options)
+        client = client_class(client_options=options, transport=transport_name)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file=None,
@@ -461,7 +461,7 @@ def test_artifact_registry_client_client_options_credentials_file(
     options = client_options.ClientOptions(credentials_file="credentials.json")
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(transport=transport_name, client_options=options)
+        client = client_class(client_options=options, transport=transport_name)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file="credentials.json",
@@ -494,9 +494,8 @@ def test_artifact_registry_client_client_options_from_dict():
         )
 
 
-def test_list_docker_images(
-    transport: str = "grpc", request_type=artifact.ListDockerImagesRequest
-):
+@pytest.mark.parametrize("request_type", [artifact.ListDockerImagesRequest, dict,])
+def test_list_docker_images(request_type, transport: str = "grpc"):
     client = ArtifactRegistryClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -525,10 +524,6 @@ def test_list_docker_images(
     assert response.next_page_token == "next_page_token_value"
 
 
-def test_list_docker_images_from_dict():
-    test_list_docker_images(request_type=dict)
-
-
 def test_list_docker_images_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -657,7 +652,9 @@ def test_list_docker_images_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-        assert args[0].parent == "parent_value"
+        arg = args[0].parent
+        mock_val = "parent_value"
+        assert arg == mock_val
 
 
 def test_list_docker_images_flattened_error():
@@ -695,7 +692,9 @@ async def test_list_docker_images_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-        assert args[0].parent == "parent_value"
+        arg = args[0].parent
+        mock_val = "parent_value"
+        assert arg == mock_val
 
 
 @pytest.mark.asyncio
@@ -712,8 +711,10 @@ async def test_list_docker_images_flattened_error_async():
         )
 
 
-def test_list_docker_images_pager():
-    client = ArtifactRegistryClient(credentials=ga_credentials.AnonymousCredentials,)
+def test_list_docker_images_pager(transport_name: str = "grpc"):
+    client = ArtifactRegistryClient(
+        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -752,8 +753,10 @@ def test_list_docker_images_pager():
         assert all(isinstance(i, artifact.DockerImage) for i in results)
 
 
-def test_list_docker_images_pages():
-    client = ArtifactRegistryClient(credentials=ga_credentials.AnonymousCredentials,)
+def test_list_docker_images_pages(transport_name: str = "grpc"):
+    client = ArtifactRegistryClient(
+        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -862,9 +865,8 @@ async def test_list_docker_images_async_pages():
             assert page_.raw_page.next_page_token == token
 
 
-def test_list_repositories(
-    transport: str = "grpc", request_type=repository.ListRepositoriesRequest
-):
+@pytest.mark.parametrize("request_type", [repository.ListRepositoriesRequest, dict,])
+def test_list_repositories(request_type, transport: str = "grpc"):
     client = ArtifactRegistryClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -893,10 +895,6 @@ def test_list_repositories(
     assert response.next_page_token == "next_page_token_value"
 
 
-def test_list_repositories_from_dict():
-    test_list_repositories(request_type=dict)
-
-
 def test_list_repositories_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -1027,7 +1025,9 @@ def test_list_repositories_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-        assert args[0].parent == "parent_value"
+        arg = args[0].parent
+        mock_val = "parent_value"
+        assert arg == mock_val
 
 
 def test_list_repositories_flattened_error():
@@ -1065,7 +1065,9 @@ async def test_list_repositories_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-        assert args[0].parent == "parent_value"
+        arg = args[0].parent
+        mock_val = "parent_value"
+        assert arg == mock_val
 
 
 @pytest.mark.asyncio
@@ -1082,8 +1084,10 @@ async def test_list_repositories_flattened_error_async():
         )
 
 
-def test_list_repositories_pager():
-    client = ArtifactRegistryClient(credentials=ga_credentials.AnonymousCredentials,)
+def test_list_repositories_pager(transport_name: str = "grpc"):
+    client = ArtifactRegistryClient(
+        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1124,8 +1128,10 @@ def test_list_repositories_pager():
         assert all(isinstance(i, repository.Repository) for i in results)
 
 
-def test_list_repositories_pages():
-    client = ArtifactRegistryClient(credentials=ga_credentials.AnonymousCredentials,)
+def test_list_repositories_pages(transport_name: str = "grpc"):
+    client = ArtifactRegistryClient(
+        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1240,9 +1246,8 @@ async def test_list_repositories_async_pages():
             assert page_.raw_page.next_page_token == token
 
 
-def test_get_repository(
-    transport: str = "grpc", request_type=repository.GetRepositoryRequest
-):
+@pytest.mark.parametrize("request_type", [repository.GetRepositoryRequest, dict,])
+def test_get_repository(request_type, transport: str = "grpc"):
     client = ArtifactRegistryClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1275,10 +1280,6 @@ def test_get_repository(
     assert response.kms_key_name == "kms_key_name_value"
 
 
-def test_get_repository_from_dict():
-    test_get_repository(request_type=dict)
-
-
 def test_get_repository_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -1405,7 +1406,9 @@ def test_get_repository_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-        assert args[0].name == "name_value"
+        arg = args[0].name
+        mock_val = "name_value"
+        assert arg == mock_val
 
 
 def test_get_repository_flattened_error():
@@ -1441,7 +1444,9 @@ async def test_get_repository_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-        assert args[0].name == "name_value"
+        arg = args[0].name
+        mock_val = "name_value"
+        assert arg == mock_val
 
 
 @pytest.mark.asyncio
@@ -2017,7 +2022,7 @@ def test_parse_common_location_path():
     assert expected == actual
 
 
-def test_client_withDEFAULT_CLIENT_INFO():
+def test_client_with_default_client_info():
     client_info = gapic_v1.client_info.ClientInfo()
 
     with mock.patch.object(
